//////////////////////////////////////////////////////////////
// CVideoWnd : MFC Video klasa
// Copyright (c) Drljaca Predrag
//
// Definicija klase CVideoWnd preko Video for Windows
//////////////////////////////////////////////////////////////

#ifndef _VIDEOWND_H
#define _VIDEOWND_H

#include <vfw.h>

typedef const char* CSTR;

class CVideoWnd : public CWnd 
{
	private:
		DECLARE_DYNCREATE(CVideoWnd)
		
		//deklarisemo sve call back funkcije koje ce pozivati virtuelne
		//funkcije kako bi obezbedili funkcionalnost u nasledjivanju
		static LRESULT PASCAL CBCapControl(HWND);
		static LRESULT PASCAL CBError(HWND, int, LPSTR);
		static LRESULT PASCAL CBFrame(HWND, LPVIDEOHDR);
		static LRESULT PASCAL CBStatus(HWND, int, LPSTR);
		static LRESULT PASCAL CBVideoStream(HWND, LPVIDEOHDR);
		static LRESULT PASCAL CBWaveStream(HWND, LPWAVEHDR);
		static LRESULT PASCAL CBYield(HWND);
		
	public:
		CVideoWnd();
		~CVideoWnd();

		BOOL Create(LPCSTR pszTitle, DWORD dwStyle, 
			int id, CRect& rc, CWnd* pWndParent);

	// implementacije virtulene callback funkcije
		virtual LRESULT OnCapControl();
		virtual LRESULT OnError(int id, LPSTR msg);
		virtual LRESULT OnFrame(LPVIDEOHDR lpVH);
		virtual LRESULT OnStatus(int id, LPSTR msg);
		virtual LRESULT OnVideoStream(LPVIDEOHDR lpVH);
		virtual LRESULT OnWaveStream(LPWAVEHDR lpWH);
		virtual LRESULT OnYield();
		
	//prebacivanje AviCap funkcija u omot C++/MFC
		BOOL CaptureAbort()
			{ return capCaptureAbort(m_hWnd); }
		BOOL CaptureGetSetup(CAPTUREPARMS &cp)
			{ return capCaptureGetSetup(m_hWnd, &cp, sizeof(CAPTUREPARMS)); }
		BOOL CaptureSequence()
			{ return capCaptureSequence(m_hWnd); }
		BOOL CaptureSequenceNoFile()
			{ return capCaptureSequenceNoFile(m_hWnd); }
		BOOL CaptureSetSetup(CAPTUREPARMS &cp)
			{ return capCaptureSetSetup(m_hWnd, &cp, sizeof(CAPTUREPARMS)); }
		BOOL CaptureSingleFrame()
			{ return capCaptureSingleFrame(m_hWnd); }
		BOOL CaptureSingleFrameClose()
			{ return capCaptureSingleFrameClose(m_hWnd); }
		BOOL CaptureSingleFrameOpen()
			{ return capCaptureSingleFrameOpen(m_hWnd); }			
		BOOL CaptureStop()
			{ return capCaptureStop(m_hWnd); }
		
		
		BOOL DlgVideoCompression()
			{ return capDlgVideoCompression(m_hWnd);}
		BOOL DlgVideoDisplay()
			{ return capDlgVideoDisplay(m_hWnd);}
		BOOL DlgVideoFormat()
			{ return capDlgVideoFormat(m_hWnd);}
		BOOL DlgVideoSource()
			{ return capDlgVideoSource(m_hWnd);}
			
		BOOL DriverConnect(int iDriver=0)	
			{ return capDriverConnect(m_hWnd,iDriver);}
		BOOL DriverDisconnect()	
			{ return capDriverDisconnect(m_hWnd); }
		BOOL DriverGetCaps(CAPDRIVERCAPS& caps)
			{ return capDriverGetCaps(m_hWnd, &caps ,sizeof(CAPDRIVERCAPS) ); }		
		BOOL DriverGetName(LPSTR szName, WORD wSize)
			{ return capDriverGetName(m_hWnd, szName, wSize); }
		BOOL DriverGetVersion(LPSTR szVer, WORD wSize)
			{ return capDriverGetVersion(m_hWnd, szVer,wSize);} 
		
		
		BOOL EditCopy()
			{ return capEditCopy(m_hWnd); }

	
		BOOL FileAlloc(DWORD dwSize)
			{ return capFileAlloc(m_hWnd, dwSize);}
		BOOL FileGetCaptureFile(LPSTR szName, WORD wSize)
			{ return capFileGetCaptureFile(m_hWnd, szName, wSize); }
		BOOL FileSaveAs(LPCSTR szName)
			{ return capFileSaveAs(m_hWnd, szName);}
		BOOL FileSaveDIB(LPCSTR szName)
			{ return capFileSaveDIB(m_hWnd,szName);}		
		BOOL FileSetCaptureFile(LPCSTR szName)
			{ return capFileSetCaptureFile(m_hWnd, szName);}
		BOOL FileSetInfoChunk(CAPINFOCHUNK &infoChunk)
			{ return capFileSetInfoChunk(m_hWnd, &infoChunk);}
		
		
		DWORD GetAudioFormat(WAVEFORMATEX &wf)
			{ return capGetAudioFormat(m_hWnd, &wf,sizeof(WAVEFORMATEX) ); }
		DWORD GetAudioFormatSize()
			{ return capGetAudioFormatSize(m_hWnd); }
		BOOL GetMCIDeviceName(LPSTR szName, WORD wSize)
			{ return capGetMCIDeviceName(m_hWnd, szName, wSize);}
		BOOL GetStatus(CAPSTATUS &status)
			{ return capGetStatus(m_hWnd, &status, sizeof(CAPSTATUS)); }
		BOOL GetUserData()
			{ return capGetUserData(m_hWnd);}
		DWORD GetVideoFormat(LPBITMAPINFOHEADER lpBmi, WORD wSize)
			{ return capGetVideoFormat(m_hWnd, lpBmi, wSize); }
		DWORD GetVideoFormatSize()
			{ return capGetVideoFormatSize(m_hWnd);}
		

		BOOL GrabFrame()
			{ return capGrabFrame(m_hWnd); }
		BOOL GrabFrameNoStop()
			{ return capGrabFrameNoStop(m_hWnd); }
		
		BOOL Overlay(BOOL f)
			{ return capOverlay(m_hWnd, f); }
		
		BOOL PaletteAuto(int iFrames, int iColors)
			{ return capPaletteAuto(m_hWnd,	iFrames, iColors); }
		BOOL PaletteManual(BOOL fGrab, int iColors)
			{ return capPaletteManual(m_hWnd, fGrab, iColors); }
		BOOL PaletteOpen(LPCSTR szName)
			{ return capPaletteOpen(m_hWnd, szName); }
		BOOL PalettePaste()
			{ return capPalettePaste(m_hWnd); }
		BOOL PaletteSave(LPCSTR szName)
			{ return capPaletteSave(m_hWnd, szName); }
		

		BOOL Preview(BOOL f)
			{ return capPreview(m_hWnd, f); }
		BOOL PreviewRate(WORD wMilliSec)
			{ return capPreviewRate(m_hWnd, wMilliSec);}
		BOOL PreviewScale(BOOL f)
			{ return capPreviewScale(m_hWnd, f); }

		BOOL SetAudioFormat(WAVEFORMATEX &wf)
			{ return capSetAudioFormat(m_hWnd, &wf,sizeof(WAVEFORMATEX) ); }
		BOOL SetMCIDeviceName(LPCSTR szName)
			{ return capSetMCIDeviceName(m_hWnd, szName); }
		BOOL SetScrollPos(POINT p)
			{ return capSetScrollPos(m_hWnd, &p); }
		BOOL SetUserData(LONG lUser)
			{ return capSetUserData(m_hWnd,lUser);}		
		BOOL SetVideoFormat(LPBITMAPINFOHEADER lpBmi, WORD wSize)
			{ return capSetVideoFormat(m_hWnd, lpBmi, wSize); }
		
	// mala pomocna funkcija elem dobra ideja bi bila napraviti funkcije
	// za sve stringove koji se vracaju kao *char da vrnu CSrting
		CString GetDriverDescription(WORD iDriver);

	protected:
	//{{AFX_MSG(CVideoWnd)
		afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
		afx_msg void OnDestroy();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()

};

#endif // _VIDEOWND_H